# EASY-INSTALL-SCRIPT: 'argcomplete==1.9.3','activate-global-python-argcomplete'
__requires__ = 'argcomplete==1.9.3'
__import__('pkg_resources').run_script('argcomplete==1.9.3', 'activate-global-python-argcomplete')
